--- MIDI mappings for instruments and percussions
-- @module Musician.MidiMapping

local Percussion = Musician.MIDI_PERCUSSIONS
local Instrument = Musician.MIDI_INSTRUMENTS

-- General MIDI instrument ID mapping to internal instrument ID
Musician.MIDI_INSTRUMENT_MAPPING = {
	-- Piano
	[Instrument.AcousticGrandPiano] = "dulcimer",
	[Instrument.BrightAcousticPiano] = "dulcimer",
	[Instrument.ElectricGrandPiano] = "dulcimer",
	[Instrument.HonkyTonkPiano] = "dulcimer",
	[Instrument.ElectricPiano1] = "dulcimer",
	[Instrument.ElectricPiano2] = "dulcimer",
	[Instrument.Harpsichord] = "harp",
	[Instrument.Clavi] = "harp",

	-- Chromatic Percussion
	[Instrument.Celesta] = "dulcimer",
	[Instrument.Glockenspiel] = "dulcimer",
	[Instrument.MusicBox] = "harp",
	[Instrument.Vibraphone] = "dulcimer",
	[Instrument.Marimba] = "dulcimer",
	[Instrument.Xylophone] = "dulcimer",
	[Instrument.TubularBells] = "dulcimer",
	[Instrument.Dulcimer] = "dulcimer",

	-- Organ
	[Instrument.DrawbarOrgan] = "accordion",
	[Instrument.PercussiveOrgan] = "accordion",
	[Instrument.RockOrgan] = "accordion",
	[Instrument.ChurchOrgan] = "accordion",
	[Instrument.ReedOrgan] = "accordion",
	[Instrument.Accordion] = "accordion",
	[Instrument.Harmonica] = "accordion",
	[Instrument.TangoAccordion] = "accordion",

	-- Guitar
	[Instrument.AcousticGuitarNylon] = "lute",
	[Instrument.AcousticGuitarSteel] = "lute",
	[Instrument.ElectricGuitarJazz] = "clean-guitar",
	[Instrument.ElectricGuitarClean] = "clean-guitar",
	[Instrument.ElectricGuitarMuted] = "clean-guitar",
	[Instrument.OverdrivenGuitar] = "distortion-guitar",
	[Instrument.DistortionGuitar] = "distortion-guitar",
	[Instrument.Guitarharmonics] = "distortion-guitar",

	-- Bass
	[Instrument.AcousticBass] = "lute",
	[Instrument.ElectricBassFinger] = "bass-guitar",
	[Instrument.ElectricBassPick] = "bass-guitar",
	[Instrument.FretlessBass] = "bass-guitar",
	[Instrument.SlapBass1] = "bass-guitar",
	[Instrument.SlapBass2] = "bass-guitar",
	[Instrument.SynthBass1] = "bass-guitar",
	[Instrument.SynthBass2] = "bass-guitar",

	-- Strings
	[Instrument.Violin] = "fiddle",
	[Instrument.Viola] = "fiddle",
	[Instrument.Cello] = "viola-da-gamba",
	[Instrument.Contrabass] = "viola-da-gamba",
	[Instrument.TremoloStrings] = "fiddle",
	[Instrument.PizzicatoStrings] = "lute",
	[Instrument.OrchestralHarp] = "harp",
	[Instrument.Timpani] = "war-drum",

	-- Ensemble
	[Instrument.StringEnsemble1] = "fiddle",
	[Instrument.StringEnsemble2] = "fiddle",
	[Instrument.SynthStrings1] = "fiddle",
	[Instrument.SynthStrings2] = "fiddle",
	[Instrument.ChoirAahs] = "male-voice",
	[Instrument.VoiceOohs] = "female-voice",
	[Instrument.SynthVoice] = "female-voice",
	[Instrument.OrchestraHit] = "lute",

	-- Brass
	[Instrument.Trumpet] = "trumpet",
	[Instrument.Trombone] = "sackbut",
	[Instrument.Tuba] = "war-horn",
	[Instrument.MutedTrumpet] = "trumpet",
	[Instrument.FrenchHorn] = "war-horn",
	[Instrument.BrassSection] = "trumpet",
	[Instrument.SynthBrass1] = "trumpet",
	[Instrument.SynthBrass2] = "trumpet",

	-- Reed
	[Instrument.SopranoSax] = "clarinet",
	[Instrument.AltoSax] = "clarinet",
	[Instrument.TenorSax] = "bassoon",
	[Instrument.BaritoneSax] = "bassoon",
	[Instrument.Oboe] = "clarinet",
	[Instrument.EnglishHorn] = "clarinet",
	[Instrument.Bassoon] = "bassoon",
	[Instrument.Clarinet] = "clarinet",

	-- Pipe
	[Instrument.Piccolo] = "recorder",
	[Instrument.Flute] = "recorder",
	[Instrument.Recorder] = "recorder",
	[Instrument.PanFlute] = "recorder",
	[Instrument.BlownBottle] = "recorder",
	[Instrument.Shakuhachi] = "recorder",
	[Instrument.Whistle] = "recorder",
	[Instrument.Ocarina] = "recorder",

	-- Synth Lead
	[Instrument.Lead1Square] = "clarinet",
	[Instrument.Lead2Sawtooth] = "fiddle",
	[Instrument.Lead3Calliope] = "recorder",
	[Instrument.Lead4Chiff] = "recorder",
	[Instrument.Lead5Charang] = "recorder",
	[Instrument.Lead6Voice] = "female-voice",
	[Instrument.Lead7Fifths] = "fiddle",
	[Instrument.Lead8BassLead] = "lute",

	-- Synth Pad
	[Instrument.Pad1Newage] = "lute",
	[Instrument.Pad2Warm] = "fiddle",
	[Instrument.Pad3Polysynth] = "fiddle",
	[Instrument.Pad4Choir] = "female-voice",
	[Instrument.Pad5Bowed] = "fiddle",
	[Instrument.Pad6Metallic] = "fiddle",
	[Instrument.Pad7Halo] = "fiddle",
	[Instrument.Pad8Sweep] = "fiddle",

	-- Synth Effects
	[Instrument.FX1Rain] = "dulcimer",
	[Instrument.FX2Soundtrack] = "dulcimer",
	[Instrument.FX3Crystal] = "dulcimer",
	[Instrument.FX4Atmosphere] = "dulcimer",
	[Instrument.FX5Brightness] = "dulcimer",
	[Instrument.FX6Goblins] = "dulcimer",
	[Instrument.FX7Echoes] = "dulcimer",
	[Instrument.FX8SciFi] = "dulcimer",

	-- Ethnic
	[Instrument.Sitar] = "harp",
	[Instrument.Banjo] = "lute",
	[Instrument.Shamisen] = "lute",
	[Instrument.Koto] = "harp",
	[Instrument.Kalimba] = "dulcimer",
	[Instrument.Bagpipe] = "bagpipe",
	[Instrument.Fiddle] = "fiddle",
	[Instrument.Shanai] = "bagpipe",

	-- Percussive
	[Instrument.TinkleBell] = "lute",
	[Instrument.Agogo] = "dulcimer",
	[Instrument.SteelDrums] = "dulcimer",
	[Instrument.Woodblock] = "woodblock",
	[Instrument.TaikoDrum] = "war-drum",
	[Instrument.MelodicTom] = "war-drum",
	[Instrument.SynthDrum] = "war-drum",
	[Instrument.ReverseCymbal] = "tambourine-shake",

	-- Sound Effects
	[Instrument.GuitarFretNoise] = "none",
	[Instrument.BreathNoise] = "none",
	[Instrument.Seashore] = "none",
	[Instrument.BirdTweet] = "none",
	[Instrument.TelephoneRing] = "none",
	[Instrument.Helicopter] = "none",
	[Instrument.Applause] = "none",
	[Instrument.Gunshot] = "none",

	-- Percussions
	[Instrument.StandardKit] = "percussions",
	[Instrument.RoomKit] = "percussions",
	[Instrument.PowerKit] = "drumkit",
	[Instrument.ElectronicKit] = "drumkit",
	[Instrument.TR808Kit] = "drumkit",
	[Instrument.JazzKit] = "percussions",
	[Instrument.BrushKit] = "percussions",
	[Instrument.OrchestraKit] = "percussions",
	[Instrument.SoundFXKit] = "none",
	[Instrument.MT32Kit] = "percussions",

	-- None
	[Instrument.None] = "none",
}

-- General MIDI percussion ID mapping to internal percussion instrument ID
-- Used for the traditional percussions set
Musician.MIDI_PERCUSSION_MAPPING = {
	[Percussion.Laser] = "none",
	[Percussion.Whip] = "none",
	[Percussion.ScratchPush] = "frame-drum-roll-1",
	[Percussion.ScratchPull] = "frame-drum-roll-2",
	[Percussion.StickClick] = "sticks",
	[Percussion.SquareClick] = "misc-hit",
	[Percussion.MetronomeClick] = "woodblock-low",
	[Percussion.MetronomeBell] = "woodblock-hi",
	[Percussion.AcousticBassDrum] = "frame-drum-kick-1",
	[Percussion.BassDrum1] = "frame-drum-kick-2",
	[Percussion.SideStick] = "cajon-hit",
	[Percussion.AcousticSnare] = "frame-drum-snare-1",
	[Percussion.HandClap] = "clap",
	[Percussion.ElectricSnare] = "frame-drum-snare-2",
	[Percussion.LowFloorTom] = "bodhran-6",
	[Percussion.ClosedHiHat] = "tambourine-short",
	[Percussion.HighFloorTom] = "bodhran-5",
	[Percussion.PedalHiHat] = "tambourine-long",
	[Percussion.LowTom] = "bodhran-4",
	[Percussion.OpenHiHat] = "tambourine-shake",
	[Percussion.LowMidTom] = "bodhran-3",
	[Percussion.HiMidTom] = "bodhran-2",
	[Percussion.CrashCymbal1] = "riq-hit-1",
	[Percussion.HighTom] = "bodhran-1",
	[Percussion.RideCymbal1] = "riq-shake-1",
	[Percussion.ChineseCymbal] = "riq-hit-3",
	[Percussion.RideBell] = "riq-hit-4",
	[Percussion.Tambourine] = "tambourine-long",
	[Percussion.SplashCymbal] = "riq-hit-5",
	[Percussion.Cowbell] = "woodblock-low",
	[Percussion.CrashCymbal2] = "riq-hit-2",
	[Percussion.Vibraslap] = "frame-drum-roll-3",
	[Percussion.RideCymbal2] = "riq-shake-2",
	[Percussion.HiBongo] = "djembe-hi-1",
	[Percussion.LowBongo] = "djembe-hi-2",
	[Percussion.MuteHiConga] = "djembe-muted",
	[Percussion.OpenHiConga] = "djembe-hi-3",
	[Percussion.LowConga] = "djembe-bass",
	[Percussion.HighTimbale] = "frame-drum-timbale-1",
	[Percussion.LowTimbale] = "frame-drum-timbale-2",
	[Percussion.HighAgogo] = "woodblock-hi",
	[Percussion.LowAgogo] = "woodblock-low",
	[Percussion.Cabasa] = "shaker",
	[Percussion.Maracas] = "shaker",
	[Percussion.ShortWhistle] = "none",
	[Percussion.LongWhistle] = "none",
	[Percussion.ShortGuiro] = "frame-drum-hit",
	[Percussion.LongGuiro] = "frame-drum-roll-3",
	[Percussion.Claves] = "claves",
	[Percussion.HiWoodBlock] = "woodblock-hi",
	[Percussion.LowWoodBlock] = "woodblock-low",
	[Percussion.MuteCuica] = "metallic-1",
	[Percussion.OpenCuica] = "metallic-2",
	[Percussion.MuteTriangle] = "none",
	[Percussion.OpenTriangle] = "none",
	[Percussion.Shaker] = "shaker",
	[Percussion.SleighBell] = "sleigh-bells",
	[Percussion.BellTree] = "sleigh-bells-shake",
	[Percussion.Castanets] = "clap",
	[Percussion.SurduDeadStroke] = "barbarian-frame-drum-dead-stroke",
	[Percussion.Surdu] = "barbarian-frame-drum",
	[Percussion.SnareDrumRod] = "none",
	[Percussion.OceanDrum] = "none",
	[Percussion.SnareDrumBrush] = "none",
}
